@@ -7,7 +7,7 @@ RDF::Query::Algebra::Filter - Algebra class for Filter expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Filter version 2.201_01, released 27 January 2010.
+This document describes RDF::Query::Algebra::Filter version 2.202_01, released 30 January 2010.
 
 =cut
 
@@ -29,7 +29,7 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.201_01';
+	$VERSION	= '2.202_01';
 }
 
 ######################################################################
@@ -195,33 +195,6 @@ sub definite_variables {
 	return $pattern->definite_variables;
 }
 
-=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
-
-Returns a new pattern that is ready for execution using the given bridge.
-This method replaces generic node objects with bridge-native objects.
-
-=cut
-
-sub fixup {
-	my $self	= shift;
-	my $class	= ref($self);
-	my $query	= shift;
-	my $bridge	= shift;
-	my $base	= shift;
-	my $ns		= shift;
-	
-	if (my $opt = $query->algebra_fixup( $self, $bridge, $base, $ns )) {
-		return $opt;
-	} else {
-		my $expr	= $self->expr;
-		if ($expr->isa('RDF::Query::Algebra')) {
-			$expr	= $expr->fixup( $query, $bridge, $base, $ns );
-		}
-		my $pattern	= $self->pattern->fixup( $query, $bridge, $base, $ns );
-		return $class->new( $expr, $pattern );
-	}
-}
-
 =item C<< is_solution_modifier >>
 
 Returns true if this node is a solution modifier.
